@@ -4,18 +4,18 @@ test setting *parts* of objects both positionally and label based
 TOD: these should be split among the indexer tests
 """
 
+from warnings import catch_warnings
+
+import numpy as np
 import pytest
 
-from warnings import catch_warnings
-import numpy as np
-
 import pandas as pd
-from pandas import Series, DataFrame, Panel, Index, date_range
+from pandas import DataFrame, Index, Series, date_range
 from pandas.util import testing as tm
 
 
-class TestPartialSetting(object):
-
+class TestPartialSetting:
+    @pytest.mark.filterwarnings("ignore:\\n.ix:FutureWarning")
     def test_partial_setting(self):
 
         # GH2578, allow ix and friends to partially set
@@ -34,145 +34,111 @@ class TestPartialSetting(object):
         tm.assert_series_equal(s, expected)
 
         s = s_orig.copy()
-        s[5] = 5.
-        expected = Series([1, 2, 3, 5.], index=[0, 1, 2, 5])
+        s[5] = 5.0
+        expected = Series([1, 2, 3, 5.0], index=[0, 1, 2, 5])
         tm.assert_series_equal(s, expected)
 
         s = s_orig.copy()
-        s.loc[5] = 5.
-        expected = Series([1, 2, 3, 5.], index=[0, 1, 2, 5])
+        s.loc[5] = 5.0
+        expected = Series([1, 2, 3, 5.0], index=[0, 1, 2, 5])
         tm.assert_series_equal(s, expected)
 
         # iloc/iat raise
         s = s_orig.copy()
 
-        def f():
-            s.iloc[3] = 5.
+        with pytest.raises(IndexError):
+            s.iloc[3] = 5.0
 
-        pytest.raises(IndexError, f)
-
-        def f():
-            s.iat[3] = 5.
-
-        pytest.raises(IndexError, f)
+        with pytest.raises(IndexError):
+            s.iat[3] = 5.0
 
         # ## frame ##
 
         df_orig = DataFrame(
-            np.arange(6).reshape(3, 2), columns=['A', 'B'], dtype='int64')
+            np.arange(6).reshape(3, 2), columns=["A", "B"], dtype="int64"
+        )
 
         # iloc/iat raise
         df = df_orig.copy()
 
-        def f():
-            df.iloc[4, 2] = 5.
+        with pytest.raises(IndexError):
+            df.iloc[4, 2] = 5.0
 
-        pytest.raises(IndexError, f)
-
-        def f():
-            df.iat[4, 2] = 5.
-
-        pytest.raises(IndexError, f)
+        with pytest.raises(IndexError):
+            df.iat[4, 2] = 5.0
 
         # row setting where it exists
-        expected = DataFrame(dict({'A': [0, 4, 4], 'B': [1, 5, 5]}))
+        expected = DataFrame(dict({"A": [0, 4, 4], "B": [1, 5, 5]}))
         df = df_orig.copy()
         df.iloc[1] = df.iloc[2]
         tm.assert_frame_equal(df, expected)
 
-        expected = DataFrame(dict({'A': [0, 4, 4], 'B': [1, 5, 5]}))
+        expected = DataFrame(dict({"A": [0, 4, 4], "B": [1, 5, 5]}))
         df = df_orig.copy()
         df.loc[1] = df.loc[2]
         tm.assert_frame_equal(df, expected)
 
         # like 2578, partial setting with dtype preservation
-        expected = DataFrame(dict({'A': [0, 2, 4, 4], 'B': [1, 3, 5, 5]}))
+        expected = DataFrame(dict({"A": [0, 2, 4, 4], "B": [1, 3, 5, 5]}))
         df = df_orig.copy()
         df.loc[3] = df.loc[2]
         tm.assert_frame_equal(df, expected)
 
         # single dtype frame, overwrite
-        expected = DataFrame(dict({'A': [0, 2, 4], 'B': [0, 2, 4]}))
+        expected = DataFrame(dict({"A": [0, 2, 4], "B": [0, 2, 4]}))
         df = df_orig.copy()
         with catch_warnings(record=True):
-            df.ix[:, 'B'] = df.ix[:, 'A']
+            df.ix[:, "B"] = df.ix[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # mixed dtype frame, overwrite
-        expected = DataFrame(dict({'A': [0, 2, 4], 'B': Series([0, 2, 4])}))
+        expected = DataFrame(dict({"A": [0, 2, 4], "B": Series([0, 2, 4])}))
         df = df_orig.copy()
-        df['B'] = df['B'].astype(np.float64)
+        df["B"] = df["B"].astype(np.float64)
         with catch_warnings(record=True):
-            df.ix[:, 'B'] = df.ix[:, 'A']
+            df.ix[:, "B"] = df.ix[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # single dtype frame, partial setting
         expected = df_orig.copy()
-        expected['C'] = df['A']
+        expected["C"] = df["A"]
         df = df_orig.copy()
         with catch_warnings(record=True):
-            df.ix[:, 'C'] = df.ix[:, 'A']
+            df.ix[:, "C"] = df.ix[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # mixed frame, partial setting
         expected = df_orig.copy()
-        expected['C'] = df['A']
+        expected["C"] = df["A"]
         df = df_orig.copy()
         with catch_warnings(record=True):
-            df.ix[:, 'C'] = df.ix[:, 'A']
+            df.ix[:, "C"] = df.ix[:, "A"]
         tm.assert_frame_equal(df, expected)
 
-        with catch_warnings(record=True):
-            # ## panel ##
-            p_orig = Panel(np.arange(16).reshape(2, 4, 2),
-                           items=['Item1', 'Item2'],
-                           major_axis=pd.date_range('2001/1/12', periods=4),
-                           minor_axis=['A', 'B'], dtype='float64')
-
-            # panel setting via item
-            p_orig = Panel(np.arange(16).reshape(2, 4, 2),
-                           items=['Item1', 'Item2'],
-                           major_axis=pd.date_range('2001/1/12', periods=4),
-                           minor_axis=['A', 'B'], dtype='float64')
-            expected = p_orig.copy()
-            expected['Item3'] = expected['Item1']
-            p = p_orig.copy()
-            p.loc['Item3'] = p['Item1']
-            tm.assert_panel_equal(p, expected)
-
-            # panel with aligned series
-            expected = p_orig.copy()
-            expected = expected.transpose(2, 1, 0)
-            expected['C'] = DataFrame({'Item1': [30, 30, 30, 30],
-                                       'Item2': [32, 32, 32, 32]},
-                                      index=p_orig.major_axis)
-            expected = expected.transpose(2, 1, 0)
-            p = p_orig.copy()
-            p.loc[:, :, 'C'] = Series([30, 32], index=p_orig.items)
-            tm.assert_panel_equal(p, expected)
-
         # GH 8473
-        dates = date_range('1/1/2000', periods=8)
-        df_orig = DataFrame(np.random.randn(8, 4), index=dates,
-                            columns=['A', 'B', 'C', 'D'])
+        dates = date_range("1/1/2000", periods=8)
+        df_orig = DataFrame(
+            np.random.randn(8, 4), index=dates, columns=["A", "B", "C", "D"]
+        )
 
-        expected = pd.concat([df_orig, DataFrame(
-            {'A': 7}, index=[dates[-1] + 1])])
+        expected = pd.concat(
+            [df_orig, DataFrame({"A": 7}, index=[dates[-1] + dates.freq])], sort=True
+        )
         df = df_orig.copy()
-        df.loc[dates[-1] + 1, 'A'] = 7
+        df.loc[dates[-1] + dates.freq, "A"] = 7
         tm.assert_frame_equal(df, expected)
         df = df_orig.copy()
-        df.at[dates[-1] + 1, 'A'] = 7
+        df.at[dates[-1] + dates.freq, "A"] = 7
         tm.assert_frame_equal(df, expected)
 
-        exp_other = DataFrame({0: 7}, index=[dates[-1] + 1])
+        exp_other = DataFrame({0: 7}, index=[dates[-1] + dates.freq])
         expected = pd.concat([df_orig, exp_other], axis=1)
 
         df = df_orig.copy()
-        df.loc[dates[-1] + 1, 0] = 7
+        df.loc[dates[-1] + dates.freq, 0] = 7
         tm.assert_frame_equal(df, expected)
         df = df_orig.copy()
-        df.at[dates[-1] + 1, 0] = 7
+        df.at[dates[-1] + dates.freq, 0] = 7
         tm.assert_frame_equal(df, expected)
 
     def test_partial_setting_mixed_dtype(self):
@@ -189,32 +155,28 @@ class TestPartialSetting(object):
         tm.assert_frame_equal(df, expected)
 
         # columns will align
-        df = DataFrame(columns=['A', 'B'])
+        df = DataFrame(columns=["A", "B"])
         df.loc[0] = Series(1, index=range(4))
-        tm.assert_frame_equal(df, DataFrame(columns=['A', 'B'], index=[0]))
+        tm.assert_frame_equal(df, DataFrame(columns=["A", "B"], index=[0]))
 
         # columns will align
-        df = DataFrame(columns=['A', 'B'])
-        df.loc[0] = Series(1, index=['B'])
+        df = DataFrame(columns=["A", "B"])
+        df.loc[0] = Series(1, index=["B"])
 
-        exp = DataFrame([[np.nan, 1]], columns=['A', 'B'],
-                        index=[0], dtype='float64')
+        exp = DataFrame([[np.nan, 1]], columns=["A", "B"], index=[0], dtype="float64")
         tm.assert_frame_equal(df, exp)
 
         # list-like must conform
-        df = DataFrame(columns=['A', 'B'])
+        df = DataFrame(columns=["A", "B"])
 
-        def f():
+        with pytest.raises(ValueError):
             df.loc[0] = [1, 2, 3]
 
-        pytest.raises(ValueError, f)
-
         # TODO: #15657, these are left as object and not coerced
-        df = DataFrame(columns=['A', 'B'])
+        df = DataFrame(columns=["A", "B"])
         df.loc[3] = [6, 7]
 
-        exp = DataFrame([[6, 7]], index=[3], columns=['A', 'B'],
-                        dtype='object')
+        exp = DataFrame([[6, 7]], index=[3], columns=["A", "B"], dtype="object")
         tm.assert_frame_equal(df, exp)
 
     def test_series_partial_set(self):
@@ -231,28 +193,33 @@ class TestPartialSetting(object):
         result = ser.reindex([3, 2, 3])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        expected = Series([np.nan, 0.2, np.nan, np.nan], index=[3, 2, 3, 'x'])
+        expected = Series([np.nan, 0.2, np.nan, np.nan], index=[3, 2, 3, "x"])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[3, 2, 3, 'x']]
+            result = ser.loc[[3, 2, 3, "x"]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        result = ser.reindex([3, 2, 3, 'x'])
+        result = ser.reindex([3, 2, 3, "x"])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         expected = Series([0.2, 0.2, 0.1], index=[2, 2, 1])
         result = ser.loc[[2, 2, 1]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        expected = Series([0.2, 0.2, np.nan, 0.1], index=[2, 2, 'x', 1])
+        expected = Series([0.2, 0.2, np.nan, 0.1], index=[2, 2, "x", 1])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[2, 2, 'x', 1]]
+            result = ser.loc[[2, 2, "x", 1]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        result = ser.reindex([2, 2, 'x', 1])
+        result = ser.reindex([2, 2, "x", 1])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         # raises as nothing in in the index
-        pytest.raises(KeyError, lambda: ser.loc[[3, 3, 3]])
+        msg = (
+            r"\"None of \[Int64Index\(\[3, 3, 3\], dtype='int64'\)\] are"
+            r" in the \[index\]\""
+        )
+        with pytest.raises(KeyError, match=msg):
+            ser.loc[[3, 3, 3]]
 
         expected = Series([0.2, 0.2, np.nan], index=[2, 2, 3])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
@@ -271,8 +238,7 @@ class TestPartialSetting(object):
         result = s.reindex([3, 4, 4])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        s = Series([0.1, 0.2, 0.3, 0.4],
-                   index=[1, 2, 3, 4])
+        s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([np.nan, 0.3, 0.3], index=[5, 3, 3])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = s.loc[[5, 3, 3]]
@@ -281,8 +247,7 @@ class TestPartialSetting(object):
         result = s.reindex([5, 3, 3])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        s = Series([0.1, 0.2, 0.3, 0.4],
-                   index=[1, 2, 3, 4])
+        s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([np.nan, 0.4, 0.4], index=[5, 4, 4])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = s.loc[[5, 4, 4]]
@@ -291,8 +256,7 @@ class TestPartialSetting(object):
         result = s.reindex([5, 4, 4])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        s = Series([0.1, 0.2, 0.3, 0.4],
-                   index=[4, 5, 6, 7])
+        s = Series([0.1, 0.2, 0.3, 0.4], index=[4, 5, 6, 7])
         expected = Series([0.4, np.nan, np.nan], index=[7, 2, 2])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = s.loc[[7, 2, 2]]
@@ -301,8 +265,7 @@ class TestPartialSetting(object):
         result = s.reindex([7, 2, 2])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        s = Series([0.1, 0.2, 0.3, 0.4],
-                   index=[1, 2, 3, 4])
+        s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([0.4, np.nan, np.nan], index=[4, 5, 5])
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = s.loc[[4, 5, 5]]
@@ -319,90 +282,89 @@ class TestPartialSetting(object):
     def test_series_partial_set_with_name(self):
         # GH 11497
 
-        idx = Index([1, 2], dtype='int64', name='idx')
-        ser = Series([0.1, 0.2], index=idx, name='s')
+        idx = Index([1, 2], dtype="int64", name="idx")
+        ser = Series([0.1, 0.2], index=idx, name="s")
 
         # loc
-        exp_idx = Index([3, 2, 3], dtype='int64', name='idx')
-        expected = Series([np.nan, 0.2, np.nan], index=exp_idx, name='s')
+        exp_idx = Index([3, 2, 3], dtype="int64", name="idx")
+        expected = Series([np.nan, 0.2, np.nan], index=exp_idx, name="s")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = ser.loc[[3, 2, 3]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([3, 2, 3, 'x'], dtype='object', name='idx')
-        expected = Series([np.nan, 0.2, np.nan, np.nan], index=exp_idx,
-                          name='s')
+        exp_idx = Index([3, 2, 3, "x"], dtype="object", name="idx")
+        expected = Series([np.nan, 0.2, np.nan, np.nan], index=exp_idx, name="s")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[3, 2, 3, 'x']]
+            result = ser.loc[[3, 2, 3, "x"]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([2, 2, 1], dtype='int64', name='idx')
-        expected = Series([0.2, 0.2, 0.1], index=exp_idx, name='s')
+        exp_idx = Index([2, 2, 1], dtype="int64", name="idx")
+        expected = Series([0.2, 0.2, 0.1], index=exp_idx, name="s")
         result = ser.loc[[2, 2, 1]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([2, 2, 'x', 1], dtype='object', name='idx')
-        expected = Series([0.2, 0.2, np.nan, 0.1], index=exp_idx, name='s')
+        exp_idx = Index([2, 2, "x", 1], dtype="object", name="idx")
+        expected = Series([0.2, 0.2, np.nan, 0.1], index=exp_idx, name="s")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[2, 2, 'x', 1]]
+            result = ser.loc[[2, 2, "x", 1]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         # raises as nothing in in the index
-        pytest.raises(KeyError, lambda: ser.loc[[3, 3, 3]])
+        msg = (
+            r"\"None of \[Int64Index\(\[3, 3, 3\], dtype='int64',"
+            r" name='idx'\)\] are in the \[index\]\""
+        )
+        with pytest.raises(KeyError, match=msg):
+            ser.loc[[3, 3, 3]]
 
-        exp_idx = Index([2, 2, 3], dtype='int64', name='idx')
-        expected = Series([0.2, 0.2, np.nan], index=exp_idx, name='s')
+        exp_idx = Index([2, 2, 3], dtype="int64", name="idx")
+        expected = Series([0.2, 0.2, np.nan], index=exp_idx, name="s")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
             result = ser.loc[[2, 2, 3]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([3, 4, 4], dtype='int64', name='idx')
-        expected = Series([0.3, np.nan, np.nan], index=exp_idx, name='s')
-        idx = Index([1, 2, 3], dtype='int64', name='idx')
+        exp_idx = Index([3, 4, 4], dtype="int64", name="idx")
+        expected = Series([0.3, np.nan, np.nan], index=exp_idx, name="s")
+        idx = Index([1, 2, 3], dtype="int64", name="idx")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3],
-                            index=idx,
-                            name='s').loc[[3, 4, 4]]
+            result = Series([0.1, 0.2, 0.3], index=idx, name="s").loc[[3, 4, 4]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([5, 3, 3], dtype='int64', name='idx')
-        expected = Series([np.nan, 0.3, 0.3], index=exp_idx, name='s')
-        idx = Index([1, 2, 3, 4], dtype='int64', name='idx')
+        exp_idx = Index([5, 3, 3], dtype="int64", name="idx")
+        expected = Series([np.nan, 0.3, 0.3], index=exp_idx, name="s")
+        idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx,
-                            name='s').loc[[5, 3, 3]]
+            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 3, 3]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([5, 4, 4], dtype='int64', name='idx')
-        expected = Series([np.nan, 0.4, 0.4], index=exp_idx, name='s')
-        idx = Index([1, 2, 3, 4], dtype='int64', name='idx')
+        exp_idx = Index([5, 4, 4], dtype="int64", name="idx")
+        expected = Series([np.nan, 0.4, 0.4], index=exp_idx, name="s")
+        idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx,
-                            name='s').loc[[5, 4, 4]]
+            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 4, 4]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([7, 2, 2], dtype='int64', name='idx')
-        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name='s')
-        idx = Index([4, 5, 6, 7], dtype='int64', name='idx')
+        exp_idx = Index([7, 2, 2], dtype="int64", name="idx")
+        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name="s")
+        idx = Index([4, 5, 6, 7], dtype="int64", name="idx")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx,
-                            name='s').loc[[7, 2, 2]]
+            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[7, 2, 2]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([4, 5, 5], dtype='int64', name='idx')
-        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name='s')
-        idx = Index([1, 2, 3, 4], dtype='int64', name='idx')
+        exp_idx = Index([4, 5, 5], dtype="int64", name="idx")
+        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name="s")
+        idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
         with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx,
-                            name='s').loc[[4, 5, 5]]
+            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[4, 5, 5]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         # iloc
-        exp_idx = Index([2, 2, 1, 1], dtype='int64', name='idx')
-        expected = Series([0.2, 0.2, 0.1, 0.1], index=exp_idx, name='s')
+        exp_idx = Index([2, 2, 1, 1], dtype="int64", name="idx")
+        expected = Series([0.2, 0.2, 0.1, 0.1], index=exp_idx, name="s")
         result = ser.iloc[[1, 1, 0, 0]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
+    @pytest.mark.filterwarnings("ignore:\\n.ix")
     def test_partial_set_invalid(self):
 
         # GH 4940
@@ -412,39 +374,30 @@ class TestPartialSetting(object):
         df = orig.copy()
 
         # don't allow not string inserts
-        def f():
+        with pytest.raises(TypeError):
             with catch_warnings(record=True):
                 df.loc[100.0, :] = df.ix[0]
 
-        pytest.raises(TypeError, f)
-
-        def f():
+        with pytest.raises(TypeError):
             with catch_warnings(record=True):
                 df.loc[100, :] = df.ix[0]
 
-        pytest.raises(TypeError, f)
-
-        def f():
+        with pytest.raises(TypeError):
             with catch_warnings(record=True):
                 df.ix[100.0, :] = df.ix[0]
 
-        pytest.raises(TypeError, f)
-
-        def f():
+        with pytest.raises(ValueError):
             with catch_warnings(record=True):
                 df.ix[100, :] = df.ix[0]
 
-        pytest.raises(ValueError, f)
-
         # allow object conversion here
         df = orig.copy()
         with catch_warnings(record=True):
-            df.loc['a', :] = df.ix[0]
-            exp = orig.append(pd.Series(df.ix[0], name='a'))
+            df.loc["a", :] = df.ix[0]
+            exp = orig.append(Series(df.ix[0], name="a"))
         tm.assert_frame_equal(df, exp)
-        tm.assert_index_equal(df.index,
-                              pd.Index(orig.index.tolist() + ['a']))
-        assert df.index.dtype == 'object'
+        tm.assert_index_equal(df.index, Index(orig.index.tolist() + ["a"]))
+        assert df.index.dtype == "object"
 
     def test_partial_set_empty_series(self):
 
@@ -458,18 +411,18 @@ class TestPartialSetting(object):
         tm.assert_series_equal(s, Series([1, 3], index=[1, 3]))
 
         s = Series()
-        s.loc[1] = 1.
-        tm.assert_series_equal(s, Series([1.], index=[1]))
-        s.loc[3] = 3.
-        tm.assert_series_equal(s, Series([1., 3.], index=[1, 3]))
+        s.loc[1] = 1.0
+        tm.assert_series_equal(s, Series([1.0], index=[1]))
+        s.loc[3] = 3.0
+        tm.assert_series_equal(s, Series([1.0, 3.0], index=[1, 3]))
 
         s = Series()
-        s.loc['foo'] = 1
-        tm.assert_series_equal(s, Series([1], index=['foo']))
-        s.loc['bar'] = 3
-        tm.assert_series_equal(s, Series([1, 3], index=['foo', 'bar']))
+        s.loc["foo"] = 1
+        tm.assert_series_equal(s, Series([1], index=["foo"]))
+        s.loc["bar"] = 3
+        tm.assert_series_equal(s, Series([1, 3], index=["foo", "bar"]))
         s.loc[3] = 4
-        tm.assert_series_equal(s, Series([1, 3, 4], index=['foo', 'bar', 3]))
+        tm.assert_series_equal(s, Series([1, 3, 4], index=["foo", "bar", 3]))
 
     def test_partial_set_empty_frame(self):
 
@@ -477,96 +430,86 @@ class TestPartialSetting(object):
         # frame
         df = DataFrame()
 
-        def f():
+        with pytest.raises(ValueError):
             df.loc[1] = 1
 
-        pytest.raises(ValueError, f)
+        with pytest.raises(ValueError):
+            df.loc[1] = Series([1], index=["foo"])
 
-        def f():
-            df.loc[1] = Series([1], index=['foo'])
-
-        pytest.raises(ValueError, f)
-
-        def f():
+        with pytest.raises(ValueError):
             df.loc[:, 1] = 1
 
-        pytest.raises(ValueError, f)
-
         # these work as they don't really change
         # anything but the index
         # GH5632
-        expected = DataFrame(columns=['foo'], index=pd.Index(
-            [], dtype='int64'))
+        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
 
         def f():
             df = DataFrame()
-            df['foo'] = Series([], dtype='object')
+            df["foo"] = Series([], dtype="object")
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
             df = DataFrame()
-            df['foo'] = Series(df.index)
+            df["foo"] = Series(df.index)
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
             df = DataFrame()
-            df['foo'] = df.index
+            df["foo"] = df.index
             return df
 
         tm.assert_frame_equal(f(), expected)
 
-        expected = DataFrame(columns=['foo'],
-                             index=pd.Index([], dtype='int64'))
-        expected['foo'] = expected['foo'].astype('float64')
+        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
+        expected["foo"] = expected["foo"].astype("float64")
 
         def f():
             df = DataFrame()
-            df['foo'] = []
+            df["foo"] = []
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
             df = DataFrame()
-            df['foo'] = Series(np.arange(len(df)), dtype='float64')
+            df["foo"] = Series(np.arange(len(df)), dtype="float64")
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
             df = DataFrame()
-            tm.assert_index_equal(df.index, pd.Index([], dtype='object'))
-            df['foo'] = range(len(df))
+            tm.assert_index_equal(df.index, Index([], dtype="object"))
+            df["foo"] = range(len(df))
             return df
 
-        expected = DataFrame(columns=['foo'],
-                             index=pd.Index([], dtype='int64'))
-        expected['foo'] = expected['foo'].astype('float64')
+        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
+        expected["foo"] = expected["foo"].astype("float64")
         tm.assert_frame_equal(f(), expected)
 
         df = DataFrame()
-        tm.assert_index_equal(df.columns, pd.Index([], dtype=object))
+        tm.assert_index_equal(df.columns, Index([], dtype=object))
         df2 = DataFrame()
-        df2[1] = Series([1], index=['foo'])
-        df.loc[:, 1] = Series([1], index=['foo'])
-        tm.assert_frame_equal(df, DataFrame([[1]], index=['foo'], columns=[1]))
+        df2[1] = Series([1], index=["foo"])
+        df.loc[:, 1] = Series([1], index=["foo"])
+        tm.assert_frame_equal(df, DataFrame([[1]], index=["foo"], columns=[1]))
         tm.assert_frame_equal(df, df2)
 
         # no index to start
-        expected = DataFrame({0: Series(1, index=range(4))},
-                             columns=['A', 'B', 0])
+        expected = DataFrame({0: Series(1, index=range(4))}, columns=["A", "B", 0])
 
-        df = DataFrame(columns=['A', 'B'])
+        df = DataFrame(columns=["A", "B"])
         df[0] = Series(1, index=range(4))
         df.dtypes
         str(df)
         tm.assert_frame_equal(df, expected)
 
-        df = DataFrame(columns=['A', 'B'])
+        df = DataFrame(columns=["A", "B"])
         df.loc[:, 0] = Series(1, index=range(4))
         df.dtypes
         str(df)
@@ -575,34 +518,32 @@ class TestPartialSetting(object):
     def test_partial_set_empty_frame_row(self):
         # GH5720, GH5744
         # don't create rows when empty
-        expected = DataFrame(columns=['A', 'B', 'New'],
-                             index=pd.Index([], dtype='int64'))
-        expected['A'] = expected['A'].astype('int64')
-        expected['B'] = expected['B'].astype('float64')
-        expected['New'] = expected['New'].astype('float64')
+        expected = DataFrame(columns=["A", "B", "New"], index=Index([], dtype="int64"))
+        expected["A"] = expected["A"].astype("int64")
+        expected["B"] = expected["B"].astype("float64")
+        expected["New"] = expected["New"].astype("float64")
 
         df = DataFrame({"A": [1, 2, 3], "B": [1.2, 4.2, 5.2]})
         y = df[df.A > 5]
-        y['New'] = np.nan
+        y["New"] = np.nan
         tm.assert_frame_equal(y, expected)
         # tm.assert_frame_equal(y,expected)
 
-        expected = DataFrame(columns=['a', 'b', 'c c', 'd'])
-        expected['d'] = expected['d'].astype('int64')
-        df = DataFrame(columns=['a', 'b', 'c c'])
-        df['d'] = 3
+        expected = DataFrame(columns=["a", "b", "c c", "d"])
+        expected["d"] = expected["d"].astype("int64")
+        df = DataFrame(columns=["a", "b", "c c"])
+        df["d"] = 3
         tm.assert_frame_equal(df, expected)
-        tm.assert_series_equal(df['c c'], Series(name='c c', dtype=object))
+        tm.assert_series_equal(df["c c"], Series(name="c c", dtype=object))
 
         # reindex columns is ok
         df = DataFrame({"A": [1, 2, 3], "B": [1.2, 4.2, 5.2]})
         y = df[df.A > 5]
-        result = y.reindex(columns=['A', 'B', 'C'])
-        expected = DataFrame(columns=['A', 'B', 'C'],
-                             index=pd.Index([], dtype='int64'))
-        expected['A'] = expected['A'].astype('int64')
-        expected['B'] = expected['B'].astype('float64')
-        expected['C'] = expected['C'].astype('float64')
+        result = y.reindex(columns=["A", "B", "C"])
+        expected = DataFrame(columns=["A", "B", "C"], index=Index([], dtype="int64"))
+        expected["A"] = expected["A"].astype("int64")
+        expected["B"] = expected["B"].astype("float64")
+        expected["C"] = expected["C"].astype("float64")
         tm.assert_frame_equal(result, expected)
 
     def test_partial_set_empty_frame_set_series(self):
@@ -611,33 +552,32 @@ class TestPartialSetting(object):
         df = DataFrame(Series())
         tm.assert_frame_equal(df, DataFrame({0: Series()}))
 
-        df = DataFrame(Series(name='foo'))
-        tm.assert_frame_equal(df, DataFrame({'foo': Series()}))
+        df = DataFrame(Series(name="foo"))
+        tm.assert_frame_equal(df, DataFrame({"foo": Series()}))
 
     def test_partial_set_empty_frame_empty_copy_assignment(self):
         # GH 5932
         # copy on empty with assignment fails
         df = DataFrame(index=[0])
         df = df.copy()
-        df['a'] = 0
-        expected = DataFrame(0, index=[0], columns=['a'])
+        df["a"] = 0
+        expected = DataFrame(0, index=[0], columns=["a"])
         tm.assert_frame_equal(df, expected)
 
     def test_partial_set_empty_frame_empty_consistencies(self):
         # GH 6171
         # consistency on empty frames
-        df = DataFrame(columns=['x', 'y'])
-        df['x'] = [1, 2]
+        df = DataFrame(columns=["x", "y"])
+        df["x"] = [1, 2]
         expected = DataFrame(dict(x=[1, 2], y=[np.nan, np.nan]))
         tm.assert_frame_equal(df, expected, check_dtype=False)
 
-        df = DataFrame(columns=['x', 'y'])
-        df['x'] = ['1', '2']
-        expected = DataFrame(
-            dict(x=['1', '2'], y=[np.nan, np.nan]), dtype=object)
+        df = DataFrame(columns=["x", "y"])
+        df["x"] = ["1", "2"]
+        expected = DataFrame(dict(x=["1", "2"], y=[np.nan, np.nan]), dtype=object)
         tm.assert_frame_equal(df, expected)
 
-        df = DataFrame(columns=['x', 'y'])
-        df.loc[0, 'x'] = 1
+        df = DataFrame(columns=["x", "y"])
+        df.loc[0, "x"] = 1
         expected = DataFrame(dict(x=[1], y=[np.nan]))
         tm.assert_frame_equal(df, expected, check_dtype=False)
